package liiga;

import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.scene.control.Alert;
import javafx.scene.control.Button;
import javafx.scene.control.ComboBox;
import javafx.scene.control.TextArea;
import javafx.stage.Stage;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.List;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Objects;


public class LisaaTulos {

    /// Nappi joka vie takaisin etusivulle
    @FXML
    private Button etusivulleNappi;

    /// Nappi jota painamalla uusi tulos tallentuu csv tiedostoon
    @FXML
    private Button lisaatulosnappi;

    /// Kenttä jossa valitaan kotijoukkue tiputusvalikosta
    @FXML
    private ComboBox<String> valitseKotijoukkue;

    /// Kenttä jossa valitaan vierasjoukkue tiputusvalikosta
    @FXML
    private ComboBox<String> valitseVierasjoukkue;

    /// Kenttä jossa valitaan lopputulos (H-D-A)
    @FXML
    private ComboBox<String> valitseLopputulos;

    /// Kenttä jossa valitaan mihin liigaan tulos lisätään
    @FXML
    private ComboBox<String> valitseLiigaNappi;

    /// Kenttä johon kirjoitetaan kotijoukkueen kerroin (ennen peliä)
    @FXML
    private TextArea homekerroin;

    /// Kenttä johon kirjoitetaan vierasjoukkueen kerroin (ennen peliä)
    @FXML
    private TextArea awaykerroin;

    /// Kenttä johon kirjoitetaan tasapelin kerroin (ennen peliä)
    @FXML
    private TextArea drawkerroin;

    public String kotijoukkue;
    public String vierasjoukkue;
    public String lopputulos;
    public String kotijoukkueenKerroin;
    public String vierasjoukkueenKerroin;
    public String tasapelinKerroin;
    public String valittuLiiga;

    /// Alustaa napit ja lisää vaihtoehdot tiputusvalikkoihin.
    @FXML
    private void initialize() {

    // Etusivu napin alustus
    etusivulleNappi.setOnAction(event -> {
        try {
            vaihdaNakyma();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    });

    // Aluksi kotijoukkue,vierasjoukkue, lopputulos ja liigan valinta on null
    valitseKotijoukkue.setValue(null);
    valitseVierasjoukkue.setValue(null);
    valitseLopputulos.setValue(null);
    valitseLiigaNappi.setValue(null);

    // Aluksi kertoimet ovat null
    homekerroin.setText("");
    awaykerroin.setText("");
    drawkerroin.setText("");


    // Lisää liigan valintanappiin arvot
    valitseLiigaNappi.getItems().addAll("Bundesliiga", "Valioliiga");

    valitseLiigaNappi.setOnAction(event -> {
        valittuLiiga = valitseLiigaNappi.getValue();
    });

    // Lisää lopputuloksen vaihtoehdot: A, D, H
    valitseLopputulos.getItems().addAll("A","D","H");

    valitseLiigaNappi.setOnAction(event -> {
        valittuLiiga = valitseLiigaNappi.getValue();

    valitseKotijoukkue.getItems().clear();
    valitseVierasjoukkue.getItems().clear();

    List<String> bundesjoukkeet = haeJoukkueet("data/bundesID.csv");
    List<String> valiojoukkueet = haeJoukkueet("data/premierID.csv");

    if ("Bundesliiga".equals(valittuLiiga)) {
            valitseKotijoukkue.getItems().addAll(bundesjoukkeet);
            valitseVierasjoukkue.getItems().addAll(bundesjoukkeet);

    } else if ("Valioliiga".equals(valittuLiiga)) {
            valitseKotijoukkue.getItems().addAll(valiojoukkueet);
            valitseVierasjoukkue.getItems().addAll(valiojoukkueet);
    }
    });

    valitseKotijoukkue.setOnAction(event -> {
        kotijoukkue = valitseKotijoukkue.getValue();
    });

    valitseVierasjoukkue.setOnAction(event -> {
        vierasjoukkue = valitseVierasjoukkue.getValue();
    });

    valitseLopputulos.setOnAction(event -> {
        lopputulos = valitseLopputulos.getValue();
    });

    lisaatulosnappi.setOnAction(event -> {
        try {
            LisaaTulosLuetteloon();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    });

    }

    /// Vaihtaa näkymäksi "avausnäkymä.fxml"
    private void vaihdaNakyma() throws IOException {

        FXMLLoader loader = new FXMLLoader(getClass().getResource("avausnakyma.fxml"));
        Parent root = loader.load();
        Stage stage = (Stage) etusivulleNappi.getScene().getWindow();
        stage.setScene(new Scene(root));
        stage.show();
    }

    @FXML
    /// Lisää käyttäjän antaman ottelun luetteloon (data -kansiossa)
    public void LisaaTulosLuetteloon() throws IOException{

    // Kertoimet saadaan käyttäjän syötteestä
    kotijoukkueenKerroin = homekerroin.getText();
    vierasjoukkueenKerroin = awaykerroin.getText();
    tasapelinKerroin = drawkerroin.getText();

    String csv;

    if(Objects.equals(valittuLiiga, "Bundesliiga")){
        csv = "data/bundesliigatulokset.csv";
    }
    else {
        csv = "data/premierliigatulokset.csv";
    }

    String lisattavaRivi = kotijoukkue + "," + vierasjoukkue + "," + kotijoukkueenKerroin + "," + vierasjoukkueenKerroin + "," + tasapelinKerroin + "," + lopputulos;

    FileWriter tiedosto = new FileWriter(csv, true);
    tiedosto.append(lisattavaRivi);
    tiedosto.append("\n");
    tiedosto.flush();

    // Kertoo käyttäjälle että tulos lisätty
    Alert ilmoitus = new Alert(Alert.AlertType.INFORMATION);
    ilmoitus.setTitle(null);
    ilmoitus.setHeaderText(null);
    ilmoitus.setContentText("Tulos on lisätty onnistuneesti! Voit nyt lisätä uuden tuloksen halutessasi");
    ilmoitus.showAndWait();

    // Alustetaan tuloksen lisäämiseen tarvittavat kentät
    valitseKotijoukkue.setValue(null);
    valitseVierasjoukkue.setValue(null);
    valitseLopputulos.setValue(null);
    valitseLiigaNappi.setValue(null);
    homekerroin.setText("");
    awaykerroin.setText("");
    drawkerroin.setText("");
    }

    /// Etsii joukkueen ID:n oikeasta tiedostosta nimen perusteella
    public int EtsiJoukkuettaVastaavaId(String joukkue) throws IOException {

        Path premierID = Paths.get("data/premierID.csv");
        Path bundesID = Paths.get("data/bundesID.csv");

        List<String> tiedosto;

        if(Objects.equals(valitseLiigaNappi.getValue(), "Bundesliiga")) {
            tiedosto = Files.readAllLines(bundesID);
        }
        else {
            tiedosto = Files.readAllLines(premierID);
        }

        int joukkueenId = Integer.MAX_VALUE;

        for (String rivi : tiedosto) {
            String[] tamaRivi;

            if (rivi.contains(joukkue)) {
                tamaRivi = rivi.split(",");
                joukkueenId = Integer.parseInt(tamaRivi[1]);
                break;
            }
        }

        return joukkueenId;
    }

    // Hakee joukkueiden nimet comboboxiin lisäämiseksi.
    public List<String> haeJoukkueet(String tiedosto) {
    List<String> joukkueet = new ArrayList<>();

    try (BufferedReader br = new BufferedReader(new FileReader(tiedosto))) {
        br.readLine(); // Ohitetaan ensimmäinen rivi (otsikko)
        String rivi;
        while ((rivi = br.readLine()) != null) {
            String[] osat = rivi.split(",");
            if (osat.length > 0) {
                joukkueet.add(osat[0].trim()); // Trimmaa mahdolliset ylimääräiset välilyönnit
            }
        }
    } catch (IOException e) {
        System.err.println("Tiedoston lukeminen epäonnistui: " + e.getMessage());
    }

    return joukkueet;
}


}
